<?php

/**
 * Fonction pour cartographier les données disponibles et les données ayant été utilisée pour un peuplement 
 *
 * Cette fonction relative à la base de donnée est distincte de l'API de Subdivisions.
 * L'API est une interface entre les données et l'utilisateur, qui permet de manipuler les opérations.
 * La présente fonction est du côté de la donnée et offre une cartographie à l'API.
 * Elle est surchargeable pour permettre de changer la mise à disposition des données.
 *
 * @plugin Subdivisions
 *
 **/

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Fonction surchargeable fournissant une cartographie des données.
 *
 * @param void|string|array $arg
 *     $arg = '' demande de tous les pays possibles
 *     $arg = "FR" demande d'un pays par son identifiant ISO3166-1 Alpha 2
 *     $arg[0]['FR'] demande d'un ou de plusieurs pays par son identifiant ISO3166-1 Alpha 2  
 *
 * @return array|string|false
 *     array tableau du peuplement
 *           pour chaque pays dispo [ISO3166-1 Alpha 2]
 *                                  => 'on' la donnée est installée
 *                                  => '' la donnée est absente 
 *     string message d'erreur (le pays demandé n'est pas dispo,...)
 *     false vous m'avez demandé n'importe quoi
 */
 
function base_subdivisions_verifier_dist ($arg = '') {

	// Vérifications

	$regex = '/^([A-Z]{2})$/';
	$pays_disponibles = pays_disponibles();
	if (($arg) AND (!is_array($arg))) {
		$arg[]=$arg;
	}
	if (!$arg) {
	$arg = $pays_disponibles;
	}
	
	// disponibilité de la donnée

	foreach ($arg as &$pays_demande) {
		$pays_demande = strtoupper ($pays_demande);
		if (!preg_match($regex, $pays_demande)) { // demande non conforme
			return _T('subdivision:verifier_pays_demande_non_conforme');
		} elseif (!in_array($pays_demande, $pays_disponibles)) { // demande pays non dispo
				return _T('subdivision:verifier_pays_non_disponible', array('nd' => $pays_demande));
		}
	}
		
	// pertinence de la donnée
	
	$carte = array_flip ($pays_disponibles);
	foreach ($carte as $cle => &$valeur) {
		if (in_array($cle, $arg)) { // la valeur dispo est demandée
			// est-il pertinent de faire une mise à jour ?
			$schema_bdd = sql_allfetsel("isocode_schema", "spip_subdivisions_schemas", "iso_pays=" . sql_quote($cle));
			if (!$schema_bdd) {
				// pas de ligne pour ce pays 
				$valeur = 'disponible'; 
			} else {
				$schema_isocode = $GLOBALS['meta']['isocode_base_version'];
				// s'il y a des points, les retirer avant de comparer les valeurs
				$schema_bdd = str_replace ( '.', '', $schema_bdd);
				$schema_isocode = str_replace ( '.', '', $schema_isocode);
				if (intval($schema_isocode) > intval($schema_bdd)) {
				// une mise à jour est nécessaire
					$valeur = 'disponible'; 
				} else {
					$valeur = 'installé'; 
				}
			}
		}
	}
			
	return $carte;		
	
}

/**
 * Fonction interne pour obtenir dans un tableau plat la liste des Pays géré par Nomenclatures Officielles
 *
 * @param null|array $arg
 *     arguments. 
 * @example : pays
 *
 *
 * @return string
 *     retourne un message d'erreur si besoin|
 */
 
function pays_disponibles () {
	$pays_disponibles = array();
	$pays_disponibles_multi = sql_allfetsel("country", "spip_iso3166subdivisions", "", "country");
	if (!$pays_disponibles_multi) {
		return _T('subdivision:verifier_spip_iso3166subdivisions_erreur');
	}
	foreach ($pays_disponibles_multi as $pays) {
		$pays_disponibles[] = $pays['country'];
	}
	return $pays_disponibles;

}
